#ifndef NT2_CORE_INCLUDE_FUNCTIONS_GLOBALNORMP_HPP_INCLUDED
#define NT2_CORE_INCLUDE_FUNCTIONS_GLOBALNORMP_HPP_INCLUDED

#include <nt2/core/functions/globalnormp.hpp>
#include <nt2/core/functions/expr/globalnormp.hpp>
#include <nt2/core/functions/scalar/globalnormp.hpp>

#endif
